@@ -1,6 +1,18 @@
-from .imports import *
-from .dashboard import *
-from .calculate_shap import *
+import os
+#
+# path= os.path.join(os.getcwd(),"explainx/lib")
+
+
+from pathlib import Path
+path= Path(__file__).parent.absolute()
+path= os.path.join(path, "lib")
+import sys
+sys.path.append(path)
+print(path)
+
+from imports import *
+from dashboard import *
+from calculate_shap import *
 """
 This class calculates feature importance
 
@@ -17,8 +29,8 @@ class explain():
 
 
     def ai(self,  df,  y, model, model_name="xgboost", mode=None):
-        y_variable= "y_variable"
-        y_variable_predict= "prediction"
+        y_variable= "y_actual"
+        y_variable_predict= "y_prediction"
 
 
 
@@ -30,9 +42,14 @@ class explain():
         if model_name=="xgboost":
             self.df_final[y_variable_predict] = model.predict(xgboost.DMatrix(df))
 
-        if model_name=="catboost":
+        elif model_name=="catboost":
             self.df_final[y_variable_predict] = model.predict(df.to_numpy())
 
+        else:
+            self.df_final[y_variable_predict] = model.predict(df.to_numpy())
+
+
+
         self.df_final[y_variable] = y
 
         d= dashboard()
@@ -47,6 +64,16 @@ class explain():
         return X,y
 
 
+    def dataset_heloc(self):
+        dataset= pd.read_csv("explainx/datasets/heloc_dataset.csv")
+
+        map_riskperformance= {"RiskPerformance": {"Good":1, "Bad":0}}
+        dataset.replace(map_riskperformance, inplace=True)
+        y= list(dataset["RiskPerformance"])
+        X= dataset.drop("RiskPerformance", axis=1)
+        return X,y
+
+
 
 
 
